# coding=utf-8
import requests
from .Memoize import memoized

url = "https://cortex.aws.lmig.com/rest/v1/textanalytics"
bag_of_words = "/bw"
named_entity_recognition = "/ner"
high_value_tags = "/recommendtags"
sentiment = "/sentiment"
parse_to_text = "/parsetotext"

class TextAnalytics(object):

    __token = ""
    def __init__(self, token):
        self.__token = token
        pass

    @memoized
    def __useService(self, service, text):
        data = {'text': text, 'token': self.__token}
        r = requests.post(url + service + "/text", data=data, timeout=30)
        return r

    @memoized
    def __useServiceFile(self, service, file, usener='FALSE'):
        data = {'file': (file, open(file, 'rb'))}
        data_token = {'token': self.__token, 'useNER': usener}
        r = requests.post(url + service + "/file", files=data, data=data_token, timeout=600)
        return r

    @memoized
    def __useCsvService(self, service, file, column, usener='FALSE'):
        data = {'file': (file, open(file, 'rb'))}
        data_token = {'token': self.__token, 'columns': column}
        r = requests.post(url + "/csv/" + service + "/file", files=data, data=data_token, timeout=600)
        return r

    def getSentiment(self, text):
        return self.__useService(sentiment, text).json()

    def getCSVSentiment(self, file, column=0):
        return self.__useCsvService(sentiment, file, column).json()

    def getHVT(self, text):
        return self.__useService(high_value_tags, text).json()

    def getHVTfile(self, path, usener='FALSE'):
        return self.__useServiceFile(high_value_tags, path, usener).json()

    def getNER(self, text):
        return self.__useService(named_entity_recognition, text).json()

    def getBOW(self, text):
        return self.__useService(bag_of_words, text).json()

    def getText(self, path):
        return self.__useServiceFile(parse_to_text, path, 'FALSE').json()
